@@ -5,4 +5,8 @@ GaussianMixture
 
 from ._best_k import (
 Silhouette
+)
+
+from ._evaluation import (
+compute_clustering_accuracy
 )
\ No newline at end of file
